@@ -1,5 +1,7 @@
 import sys
 from string import Formatter
+from distutils.version import LooseVersion
+from requests import __version__ as requests_version
 
 
 def to_string(string):
@@ -7,6 +9,11 @@ def to_string(string):
     return string.encode('utf-8') if sys.version_info[0] < 3 else string
 
 
+def json_response(json_):
+    """Requests had json as a property until 1.0.0 and as a method afterwards"""
+    return json_() if LooseVersion(requests_version) >= LooseVersion('1.0.0') else json_
+
+
 class MemorizeFormatter(Formatter):
     """Memorizes all arguments, used during string formatting"""
     def __init__(self):
